@@ -257,7 +257,8 @@ public:
         switch (role) {
         case Qt::DisplayRole: {
             const auto userID = key.userID(0);
-            QString name, email;
+            QString name;
+            QString email;
 
             if (key.protocol() == GpgME::OpenPGP) {
                 name = QString::fromUtf8(userID.name());
@@ -435,7 +436,7 @@ KeySelectionCombo::KeySelectionCombo(bool secretOnly, QWidget* parent)
     d->proxyModel->setSourceModel(d->sortFilterProxy);
 
     setModel(d->proxyModel);
-    connect(this, QOverload<int>::of(&QComboBox::currentIndexChanged),
+    connect(this, qOverload<int>(&QComboBox::currentIndexChanged),
             this, [this](int row) {
                 if (row >= 0 && row < d->proxyModel->rowCount()) {
                     if (d->proxyModel->isCustomItem(row)) {
@@ -464,10 +465,7 @@ KeySelectionCombo::KeySelectionCombo(bool secretOnly, QWidget* parent)
     QTimer::singleShot(0, this, &KeySelectionCombo::init);
 }
 
-KeySelectionCombo::~KeySelectionCombo()
-{
-    delete d;
-}
+KeySelectionCombo::~KeySelectionCombo() = default;
 
 void KeySelectionCombo::init()
 {
@@ -509,7 +507,7 @@ void KeySelectionCombo::init()
         Q_EMIT keyListingFinished();
     }
 
-    connect(this, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this] () {
+    connect(this, qOverload<int>(&QComboBox::currentIndexChanged), this, [this] () {
             setToolTip(currentData(Qt::ToolTipRole).toString());
         });
 }
